Step

Struct Step 

pub struct Step<O, A, F = Reward, U = O> {
    pub observation: O,
    pub action: A,
    pub feedback: F,
    pub next: Successor<O, U>,
}
Description of an environment step.

There are a few different forms that this structure can take in terms of describing the next observation when next is Successor::Continue. These are determined by the value of the fourth generic parameter U:

  • Step<O, A, F> - U = O - The continuing successor observation is owned.
  • TransientStep<O, A, F> - U = &O - The continuing successor observation is borrowed.
  • PartialStep<O, A, F> - U = () - The continuing successor observation is omitted.

If next is Successor::Interrupt then the observation is owned in all cases.

Fields

observation: O

The initial observation.

action: A

The action taken from the initial state given the initial observation.

feedback: F

The resulting feedback.

next: Successor<O, U>

The next observation or outcome; how the episode progresses.

Implementations

Source

impl<O, A, F, U> Step<O, A, F, U>

pub const fn new( observation: O, action: A, feedback: F, next: Successor<O, U>, ) -> Self

pub const fn episode_done(&self) -> bool

Whether this step is the last of an episode.

pub fn into_partial(self) -> PartialStep<O, A, F>

Source

impl<O: Clone, A, F> Step<O, A, F, &O>

pub fn into_owned(self) -> Step<O, A, F>

Convert a transient step into an owned step by cloning any borrowed successor observation.

Source

impl<O, A, F> Step<O, A, F, ()>

pub fn into_transient_with(self, next: &Self) -> TransientStep<'_, O, A, F>

Convert a partial step into a transient step using the given reference to the next step.

pub fn try_into_transient<'a>(self) -> Option<TransientStep<'a, O, A, F>>

Try to convert into a transient step with no successor.

Succeeds so long as self.next is not Successor::Continue.