pub trait Forward {
// Required method
fn forward(&self, input: &Tensor) -> Tensor;
}Expand description
A feed-forward function of a tensor.
This is roughtly equivalent to PyTorch’s module class except it is not treated as
the base interface of all modules because not all modules implement the batch
Tensor -> Tensor transformation.